@@ -21,14 +21,9 @@ sub result {
 
   my $result =
     ($result_type eq 'n')
-    ? eval { $self->calculate($op1->{value}, $op2->{value}) }
+    ? $self->calculate($op1->{value}, $op2->{value})
     : 0;
 
-  if ($@) {
-    $result      = $@->{message} || 'Invalid arguments';
-    $result_type = $@->{type}    || 'e#NUM!';
-  }
-
   return { type => $result_type, value => $result };
 
 }
